@@ -169,3 +169,33 @@ class Proxy(object):
     Inverse of __eq__.
     '''
     return not self.__eq__(other)
+
+def parseColorString(color_string):
+  '''
+  Parse a string representation of a 24-bit color, and a 8 bit alpha mask.
+
+  @param color_string: String in the format: #rrbbggaa.
+  @type color_string: string
+
+  @return: A color string in the format of #rrggbb, and an opacity value 
+  of 0.0 to 1.0
+  @rtype: tuple of string and float.
+  '''
+  return color_string[:-2], long(color_string[-2:], 16)/255.0
+
+def getTreePathBoundingBox(treeview, path, col):
+  '''
+  Get bounding box of given tree path.
+  '''
+  gdkwindow = treeview.window
+  x, y = treeview.allocation.x, treeview.allocation.y
+  while gdkwindow:
+    window_x, window_y = gdkwindow.get_position()
+    x += window_x
+    y += window_y
+    gdkwindow = gdkwindow.get_parent()
+  rect = treeview.get_cell_area(path, col)
+  rect.x, rect.y = treeview.tree_to_widget_coords(rect.x, rect.y)
+  rect.x += x
+  rect.y += y
+  return rect
